==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/fr/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ce trim.",
	"field-quarter-short-relative+1": "le trim. proch.",
	"field-tue-relative+-1": "mardi dernier",
	"field-year": "année",
	"field-wed-relative+0": "ce mercredi",
	"field-wed-relative+1": "mercredi prochain",
	"field-minute": "minute",
	"field-tue-narrow-relative+0": "ce mar",
	"field-tue-narrow-relative+1": "mar proch",
	"field-thu-short-relative+0": "ce jeu.",
	"field-thu-short-relative+1": "jeu. prochain",
	"field-day-relative+0": "aujourd’hui",
	"field-day-relative+1": "demain",
	"field-day-relative+2": "après-demain",
	"field-wed-narrow-relative+-1": "mer dern",
	"field-year-narrow": "a",
	"field-tue-relative+0": "ce mardi",
	"field-tue-relative+1": "mardi prochain",
	"field-second-short": "s",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "cette semaine",
	"field-month-relative+0": "ce mois-ci",
	"field-week-relative+1": "la semaine prochaine",
	"field-month-relative+1": "le mois prochain",
	"field-sun-narrow-relative+0": "ce dim",
	"field-mon-short-relative+0": "ce lun.",
	"field-sun-narrow-relative+1": "dim proch",
	"field-mon-short-relative+1": "lun. prochain",
	"field-second-relative+0": "maintenant",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-month-short": "m.",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "jour",
	"field-year-relative+-1": "l’année dernière",
	"field-sat-short-relative+-1": "sam. dernier",
	"field-hour-relative+0": "cette heure-ci",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-wed-relative+-1": "mercredi dernier",
	"field-sat-narrow-relative+-1": "sam dern",
	"field-second": "seconde",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "cette h",
	"field-quarter": "trimestre",
	"field-week-short": "sem.",
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"field-tue-short-relative+0": "ce mar.",
	"field-tue-short-relative+1": "mar. prochain",
	"field-mon-relative+-1": "lundi dernier",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "mois",
	"field-day-narrow": "j",
	"field-minute-short": "min",
	"field-dayperiod": "cadran",
	"field-sat-short-relative+0": "ce sam.",
	"field-sat-short-relative+1": "sam. prochain",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ce lundi",
	"field-mon-relative+1": "lundi prochain",
	"field-year-short": "an",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-quarter-relative+-1": "le trimestre dernier",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"field-sat-relative+-1": "samedi dernier",
	"dateTimeFormat-long": "{1} 'à' {0}",
	"dateFormatItem-Md": "d/M",
	"field-minute-narrow-relative+0": "cette min",
	"field-hour": "heure",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dateFormat-full": "EEEE d MMMM y G",
	"field-month-relative+-1": "le mois dernier",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "ce sam",
	"field-fri-relative+0": "ce vendredi",
	"field-sat-narrow-relative+1": "sam proch",
	"field-fri-relative+1": "vendredi prochain",
	"field-sun-short-relative+0": "ce dim.",
	"field-sun-short-relative+1": "dim. prochain",
	"field-week-relative+-1": "la semaine dernière",
	"field-quarter-short-relative+-1": "le trim. dern.",
	"field-minute-short-relative+0": "cette min",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"field-quarter-relative+0": "ce trimestre",
	"field-minute-relative+0": "cette minute-ci",
	"field-quarter-relative+1": "le trimestre prochain",
	"field-wed-short-relative+-1": "mer. dernier",
	"dateFormat-short": "dd/MM/y GGGGG",
	"field-thu-short-relative+-1": "jeu. dernier",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"field-mon-narrow-relative+-1": "lun dern",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "jeu dern",
	"field-tue-narrow-relative+-1": "mar dern",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "ce mer.",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"field-wed-short-relative+1": "mer. prochain",
	"field-sun-relative+-1": "dimanche dernier",
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dateTimeFormat-full": "{1} 'à' {0}",
	"field-weekday": "jour de la semaine",
	"field-quarter-narrow-relative+0": "ce trim",
	"field-sat-relative+0": "ce samedi",
	"field-quarter-narrow-relative+1": "trim proch",
	"field-sat-relative+1": "samedi prochain",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"dateFormatItem-MEd": "E d/M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "ce jeu",
	"field-thu-narrow-relative+1": "jeu proch",
	"field-sun-narrow-relative+-1": "dim dern",
	"field-mon-short-relative+-1": "lun. dernier",
	"field-thu-relative+0": "ce jeudi",
	"field-thu-relative+1": "jeudi prochain",
	"field-fri-short-relative+-1": "ven. dernier",
	"field-thu-relative+-1": "jeudi dernier",
	"field-week": "semaine",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "ce mer",
	"field-wed-narrow-relative+1": "mer proch",
	"field-quarter-narrow-relative+-1": "trim dern",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-fri-short-relative+0": "ce ven.",
	"field-fri-short-relative+1": "ven. prochain",
	"days-standAlone-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"field-hour-narrow-relative+0": "cette h",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"field-month-narrow": "m.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "ven dern",
	"field-year-relative+0": "cette année",
	"field-year-relative+1": "l’année prochaine",
	"field-fri-relative+-1": "vendredi dernier",
	"field-tue-short-relative+-1": "mar. dernier",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-mon-narrow-relative+0": "ce lun",
	"field-mon-narrow-relative+1": "lun proch",
	"field-zone": "fuseau horaire",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dim. dernier",
	"field-day-relative+-1": "hier",
	"field-day-relative+-2": "avant-hier",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"field-sun-relative+0": "ce dimanche",
	"field-sun-relative+1": "dimanche prochain",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "j",
	"field-week-narrow": "sem.",
	"field-era": "ère",
	"field-fri-narrow-relative+0": "ce ven",
	"field-fri-narrow-relative+1": "ven proch"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/fr/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ce trim.",
	"field-quarter-short-relative+1": "le trim. proch.",
	"field-tue-relative+-1": "mardi dernier",
	"field-year": "année",
	"field-wed-relative+0": "ce mercredi",
	"field-wed-relative+1": "mercredi prochain",
	"field-minute": "minute",
	"field-month-narrow-relative+-1": "le mois dernier",
	"field-tue-narrow-relative+0": "ce mar.",
	"field-tue-narrow-relative+1": "mar. prochain",
	"field-thu-short-relative+0": "ce jeu.",
	"field-day-short-relative+-1": "hier",
	"field-thu-short-relative+1": "jeu. prochain",
	"field-day-relative+0": "aujourd’hui",
	"field-day-short-relative+-2": "avant-hier",
	"field-day-relative+1": "demain",
	"field-week-narrow-relative+0": "cette semaine",
	"field-day-relative+2": "après-demain",
	"field-week-narrow-relative+1": "la semaine prochaine",
	"field-wed-narrow-relative+-1": "mer. dernier",
	"field-year-narrow": "a",
	"field-era-short": "ère",
	"field-year-narrow-relative+0": "cette année",
	"field-tue-relative+0": "ce mardi",
	"field-year-narrow-relative+1": "l’année prochaine",
	"field-tue-relative+1": "mardi prochain",
	"field-weekdayOfMonth": "jour (mois)",
	"field-second-short": "s",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "jour (mois)",
	"field-week-relative+0": "cette semaine",
	"field-month-relative+0": "ce mois-ci",
	"field-week-relative+1": "la semaine prochaine",
	"field-month-relative+1": "le mois prochain",
	"field-sun-narrow-relative+0": "ce dim.",
	"field-mon-short-relative+0": "ce lun.",
	"field-sun-narrow-relative+1": "dim. prochain",
	"field-mon-short-relative+1": "lun. prochain",
	"field-second-relative+0": "maintenant",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"Anno Persico"
	],
	"field-weekOfMonth": "semaine (mois)",
	"field-month-short": "m.",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "jour",
	"field-dayOfYear-short": "j (an)",
	"field-year-relative+-1": "l’année dernière",
	"field-sat-short-relative+-1": "sam. dernier",
	"field-hour-relative+0": "cette heure-ci",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-wed-relative+-1": "mercredi dernier",
	"field-sat-narrow-relative+-1": "sam. dernier",
	"field-second": "seconde",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "cette h",
	"field-quarter": "trimestre",
	"field-week-short": "sem.",
	"field-day-narrow-relative+0": "aujourd’hui",
	"field-day-narrow-relative+1": "demain",
	"field-day-narrow-relative+2": "après-demain",
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"field-tue-short-relative+0": "ce mar.",
	"field-tue-short-relative+1": "mar. prochain",
	"field-month-short-relative+-1": "le mois dernier",
	"field-mon-relative+-1": "lundi dernier",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "mois",
	"field-day-narrow": "j",
	"field-minute-short": "min",
	"field-dayperiod": "cadran",
	"field-sat-short-relative+0": "ce sam.",
	"field-sat-short-relative+1": "sam. prochain",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"A. P."
	],
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ce lundi",
	"field-mon-relative+1": "lundi prochain",
	"field-day-narrow-relative+-1": "hier",
	"field-year-short": "an",
	"field-day-narrow-relative+-2": "avant-hier",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "le trimestre dernier",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "cadran",
	"field-week-narrow-relative+-1": "la semaine dernière",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"field-dayOfYear": "jour (année)",
	"field-sat-relative+-1": "samedi dernier",
	"dateTimeFormat-long": "{1} 'à' {0}",
	"dateFormatItem-Md": "d/M",
	"field-minute-narrow-relative+0": "cette min",
	"field-hour": "heure",
	"months-format-wide": [
		"farvardin",
		"ordibehešt",
		"khordâd",
		"tir",
		"mordâd",
		"šahrivar",
		"mehr",
		"âbân",
		"âzar",
		"dey",
		"bahman",
		"esfand"
	],
	"dateFormat-full": "EEEE d MMMM y G",
	"field-month-relative+-1": "le mois dernier",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "ce sam.",
	"field-fri-relative+0": "ce vendredi",
	"field-sat-narrow-relative+1": "sam. prochain",
	"field-fri-relative+1": "vendredi prochain",
	"field-month-narrow-relative+0": "ce mois-ci",
	"field-month-narrow-relative+1": "le mois prochain",
	"field-sun-short-relative+0": "ce dim.",
	"field-sun-short-relative+1": "dim. prochain",
	"field-week-relative+-1": "la semaine dernière",
	"field-quarter-short-relative+-1": "le trim. dern.",
	"field-minute-short-relative+0": "cette min",
	"months-format-abbr": [
		"far.",
		"ord.",
		"kho.",
		"tir",
		"mor.",
		"šah.",
		"mehr",
		"âbân",
		"âzar",
		"dey",
		"bah.",
		"esf."
	],
	"field-quarter-relative+0": "ce trimestre",
	"field-minute-relative+0": "cette minute-ci",
	"field-quarter-relative+1": "le trimestre prochain",
	"field-wed-short-relative+-1": "mer. dernier",
	"dateFormat-short": "dd/MM/y GGGGG",
	"field-thu-short-relative+-1": "jeu. dernier",
	"field-year-narrow-relative+-1": "l’année dernière",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"field-mon-narrow-relative+-1": "lun. dernier",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "jeu. dernier",
	"field-tue-narrow-relative+-1": "mar. dernier",
	"field-weekOfMonth-short": "sem. (m.)",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "ce mer.",
	"months-standAlone-wide": [
		"farvardin",
		"ordibehešt",
		"khordâd",
		"tir",
		"mordâd",
		"šahrivar",
		"mehr",
		"âbân",
		"âzar",
		"dey",
		"bahman",
		"esfand"
	],
	"field-wed-short-relative+1": "mer. prochain",
	"field-sun-relative+-1": "dimanche dernier",
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dateTimeFormat-full": "{1} 'à' {0}",
	"field-weekday": "jour de la semaine",
	"field-day-short-relative+0": "aujourd’hui",
	"field-quarter-narrow-relative+0": "ce trim.",
	"field-sat-relative+0": "ce samedi",
	"field-day-short-relative+1": "demain",
	"field-quarter-narrow-relative+1": "trim. proch.",
	"field-day-short-relative+2": "après-demain",
	"field-sat-relative+1": "samedi prochain",
	"field-week-short-relative+0": "cette semaine",
	"field-week-short-relative+1": "la semaine prochaine",
	"months-standAlone-abbr": [
		"far.",
		"ord.",
		"kho.",
		"tir",
		"mor.",
		"šah.",
		"mehr",
		"âbân",
		"âzar",
		"dey",
		"bah.",
		"esf."
	],
	"field-dayOfYear-narrow": "j (an)",
	"field-month-short-relative+0": "ce mois-ci",
	"field-month-short-relative+1": "le mois prochain",
	"field-weekdayOfMonth-short": "jour (mois)",
	"dateFormatItem-MEd": "E d/M",
	"field-zone-narrow": "fuseau horaire",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "ce jeu.",
	"field-thu-narrow-relative+1": "jeu. prochain",
	"field-sun-narrow-relative+-1": "dim. dernier",
	"field-mon-short-relative+-1": "lun. dernier",
	"field-thu-relative+0": "ce jeudi",
	"field-thu-relative+1": "jeudi prochain",
	"field-fri-short-relative+-1": "ven. dernier",
	"field-thu-relative+-1": "jeudi dernier",
	"field-week": "semaine",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "ce mer.",
	"field-wed-narrow-relative+1": "mer. prochain",
	"field-quarter-narrow-relative+-1": "trim. dern.",
	"field-year-short-relative+0": "cette année",
	"field-dayperiod-short": "cadran",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "l’année prochaine",
	"field-fri-short-relative+0": "ce ven.",
	"field-fri-short-relative+1": "ven. prochain",
	"days-standAlone-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"field-week-short-relative+-1": "la semaine dernière",
	"field-hour-narrow-relative+0": "cette h",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"field-zone-short": "fuseau horaire",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"field-month-narrow": "m.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "ven. dernier",
	"field-year-relative+0": "cette année",
	"field-year-relative+1": "l’année prochaine",
	"field-era-narrow": "ère",
	"field-fri-relative+-1": "vendredi dernier",
	"eraNarrow": [
		"A. P."
	],
	"field-tue-short-relative+-1": "mar. dernier",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-mon-narrow-relative+0": "ce lun.",
	"field-mon-narrow-relative+1": "lun. prochain",
	"field-year-short-relative+-1": "l’année dernière",
	"field-zone": "fuseau horaire",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-weekOfMonth-narrow": "sem. (m.)",
	"field-weekday-narrow": "j (sem.)",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dim. dernier",
	"field-day-relative+-1": "hier",
	"field-day-relative+-2": "avant-hier",
	"field-weekday-short": "j (sem.)",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"field-sun-relative+0": "ce dimanche",
	"field-sun-relative+1": "dimanche prochain",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "j",
	"field-week-narrow": "sem.",
	"field-era": "ère",
	"field-fri-narrow-relative+0": "ce ven.",
	"field-fri-narrow-relative+1": "ven. prochain"
}
//end v1.x content
);
